==> webkit2gtk_2.34.1.orig.tar.xz: webkitgtk-2.34.1/Source/WebKit/Shared/IdentifierTypes.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "MonotonicObjectIdentifier.h"
#include <wtf/ObjectIdentifier.h>

namespace WebKit {

enum FormSubmitListenerIdentifierType { };
using FormSubmitListenerIdentifier = ObjectIdentifier<FormSubmitListenerIdentifierType>;

enum PageGroupIdentifierType { };
using PageGroupIdentifier = ObjectIdentifier<PageGroupIdentifierType>;

enum TapIdentifierType { };
using TapIdentifier = ObjectIdentifier<TapIdentifierType>;

enum TextCheckerRequestType { };
using TextCheckerRequestID = ObjectIdentifier<TextCheckerRequestType>;

enum EditorStateIdentifierType { };
using EditorStateIdentifier = MonotonicObjectIdentifier<EditorStateIdentifierType>;

enum FocusedElementInformationIdentifierType { };
using FocusedElementInformationIdentifier = MonotonicObjectIdentifier<FocusedElementInformationIdentifierType>;

} // namespace WebKit

==> webkit2gtk_2.46.1.orig.tar.xz: webkitgtk-2.46.1/Source/WebKit/Shared/IdentifierTypes.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "MonotonicObjectIdentifier.h"
#include <wtf/ObjectIdentifier.h>

namespace WebKit {

struct AuthenticationChallengeIdentifierType;
using AuthenticationChallengeIdentifier = LegacyNullableObjectIdentifier<AuthenticationChallengeIdentifierType>;

struct PageGroupIdentifierType;
using PageGroupIdentifier = LegacyNullableObjectIdentifier<PageGroupIdentifierType>;

struct TapIdentifierType;
using TapIdentifier = LegacyNullableObjectIdentifier<TapIdentifierType>;

struct TextCheckerRequestType;
using TextCheckerRequestID = LegacyNullableObjectIdentifier<TextCheckerRequestType>;

struct EditorStateIdentifierType;
using EditorStateIdentifier = MonotonicObjectIdentifier<EditorStateIdentifierType>;

struct FocusedElementInformationIdentifierType;
using FocusedElementInformationIdentifier = MonotonicObjectIdentifier<FocusedElementInformationIdentifierType>;

} // namespace WebKit
